pub struct TerminalFrame<'a> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a> TerminalFrame<'a>
impl<'a> TerminalFrame<'a>
Sourcepub fn panels(&self) -> impl Iterator<Item = PanelEntry<'_, Rect>>
pub fn panels(&self) -> impl Iterator<Item = PanelEntry<'_, Rect>>
All panels with quantized rects, in kind-grouped order.
Sourcepub fn overlays(&self) -> impl Iterator<Item = OverlayEntry<'_, Rect>>
pub fn overlays(&self) -> impl Iterator<Item = OverlayEntry<'_, Rect>>
Overlays with quantized rects.
Sourcepub fn focused_panels(
&self,
focused: Option<PanelId>,
) -> impl Iterator<Item = (PanelEntry<'_, Rect>, bool)>
pub fn focused_panels( &self, focused: Option<PanelId>, ) -> impl Iterator<Item = (PanelEntry<'_, Rect>, bool)>
Panels with focus flag and quantized rects.
A panel is focused when its id matches focused, or when it is a
decoration panel whose content kind matches the focused panel’s kind.
Sourcepub fn render_overlays(
&self,
frame: &mut Frame<'_>,
render: impl FnMut(&mut Frame<'_>, OverlayEntry<'_, Rect>),
)
pub fn render_overlays( &self, frame: &mut Frame<'_>, render: impl FnMut(&mut Frame<'_>, OverlayEntry<'_, Rect>), )
Clear underlying cells then render each overlay. Call after panels.
Sourcepub fn diff(&self) -> Option<LayoutDiff<'_>>
pub fn diff(&self) -> Option<LayoutDiff<'_>>
Layout diff (panel IDs, not rects). None for stateless resolves.
Sourcepub fn inner(&self) -> Option<&PanesFrame>
pub fn inner(&self) -> Option<&PanesFrame>
Raw panes Frame. None for stateless resolves.
Sourcepub fn overlay_failures(&self) -> &[(OverlayId, Arc<str>, AnchorFailure)]
pub fn overlay_failures(&self) -> &[(OverlayId, Arc<str>, AnchorFailure)]
Overlays that failed to anchor during the most recent resolve.